package com.jiuqi.dna.ide.designer.elements;

import com.jiuqi.dna.ide.designer.DesignerBase;
import com.jiuqi.dna.ide.designer.workflow.WorkflowDesignerBase;
import java.util.ArrayList;
import java.util.Iterator;
import org.eclipse.draw2d.geometry.Point;

/* loaded from: com_jiuqi_dna_ide_designer_elements.jar:com/jiuqi/dna/ide/designer/elements/LinkElement.class */
public class LinkElement extends DesignerElement implements ILinkElement {
    private static final long serialVersionUID = 8167257747988143424L;
    protected WorkflowDesignerBase workflowDeisgner;
    private IFigureElement source;
    private IFigureElement target;
    private ArrayList<IBendpointElement> bendpoints = new ArrayList<>();

    @Override // com.jiuqi.dna.ide.designer.elements.DesignerElement, com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public void init() {
        super.init();
        this.source.addSourceLink(this);
        this.target.addTargetLink(this);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.DesignerElement, com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public boolean isInitializable() {
        return getParent() != null && getParent().isInitialized() && getSource() != null && getSource().isInitialized() && getTarget() != null && getTarget().isInitialized() && !getSource().equals(getTarget()) && fireVerifyCreate();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.jiuqi.dna.ide.designer.elements.DesignerElement
    public void initProperties() {
    }

    @Override // com.jiuqi.dna.ide.designer.elements.DesignerElement, com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public void dispose() {
        if (!isInitialized()) {
            return;
        }
        this.source.removeSourceLink(this);
        this.target.removeTargetLink(this);
        this.parent.removeChild(this);
        fireDelete();
        setInitialized(false);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILinkElement
    public ArrayList<Point> getBendpoints() {
        ArrayList<Point> points = new ArrayList<>();
        Iterator<IBendpointElement> it = this.bendpoints.iterator();
        while (it.hasNext()) {
            IBendpointElement bendpoint = it.next();
            points.add(bendpoint.getLocation());
        }
        return points;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILinkElement
    public Point getBendpoint(int index) {
        return this.bendpoints.get(index).getLocation();
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILinkElement
    public void setBendpoint(int index, Point point) {
        IBendpointElement bendpoint = this.bendpoints.get(index);
        bendpoint.setLocation(point);
        fireBendpointMove(bendpoint);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILinkElement
    public void insertBendpoint(int index, Point point) {
        IBendpointElement bendpoint = new BendpointElement(index, point);
        this.bendpoints.add(index, bendpoint);
        fireBendpointCreate(bendpoint);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILinkElement
    public void removeBendpoint(int index) {
        IBendpointElement bendpoint = this.bendpoints.remove(index);
        fireBendpointDelete(bendpoint);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILinkElement
    public IFigureElement getSource() {
        return this.source;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILinkElement
    public IFigureElement getTarget() {
        return this.target;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILinkElement
    public boolean isChangeable(IFigureElement node, boolean isSourceChange) {
        return fireVerifyChange(node, isSourceChange);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILinkElement
    public void setSource(IFigureElement source) {
        IFigureElement oldSource = this.source;
        this.source = source;
        fireChange(oldSource, true);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILinkElement
    public void setTarget(IFigureElement target) {
        IFigureElement oldTarget = this.target;
        this.target = target;
        fireChange(oldTarget, false);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILinkElement
    public boolean canCreateBendpoint(int index, Point point) {
        IBendpointElement bendpoint = new BendpointElement(index, point);
        return fireVerifyCreateBendpoint(bendpoint);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILinkElement
    public boolean canDeleteBendpoint(int index) {
        IBendpointElement bendpoint = this.bendpoints.get(index);
        return fireVerifyDeleteBendpoint(bendpoint);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILinkElement
    public boolean canMoveBendpoint(int index, Point point) {
        IBendpointElement bendpoint = this.bendpoints.get(index);
        return fireVerifyMoveBendpoint(bendpoint);
    }

    public boolean equals(Object obj) {
        if (obj instanceof LinkElement) {
            LinkElement link = (LinkElement) obj;
            return this.source == link.source && this.target == link.target;
        }
        return super.equals(obj);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.DesignerElement
    public void setDesigner(DesignerBase designer) {
        if (designer instanceof WorkflowDesignerBase) {
            this.workflowDeisgner = (WorkflowDesignerBase) designer;
        }
        super.setDesigner(designer);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.jiuqi.dna.ide.designer.elements.DesignerElement
    public void fireCreate() {
        if (this.workflowDeisgner != null) {
            this.workflowDeisgner.fireLinkCreate(this);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.jiuqi.dna.ide.designer.elements.DesignerElement
    public void fireDelete() {
        if (this.workflowDeisgner != null && isInitialized()) {
            this.workflowDeisgner.fireLinkDelete(this);
        }
    }

    protected void fireChange(IFigureElement oldNode, boolean sourceChanged) {
        if (this.workflowDeisgner != null && isInitialized()) {
            this.workflowDeisgner.fireLinkChange(this, oldNode, sourceChanged);
        }
    }

    protected void fireBendpointCreate(IBendpointElement bendpoint) {
        if (this.workflowDeisgner != null && isInitialized()) {
            this.workflowDeisgner.fireBendpointCreate(this, bendpoint.getIndex(), bendpoint.getLocation());
        }
    }

    protected void fireBendpointDelete(IBendpointElement bendpoint) {
        if (this.workflowDeisgner != null && isInitialized()) {
            this.workflowDeisgner.fireBendpointDelete(this, bendpoint.getIndex(), bendpoint.getLocation());
        }
    }

    protected void fireBendpointMove(IBendpointElement bendpoint) {
        if (this.workflowDeisgner != null && isInitialized()) {
            this.workflowDeisgner.fireBendpointMove(this, bendpoint.getIndex(), bendpoint.getLocation());
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.jiuqi.dna.ide.designer.elements.DesignerElement
    public boolean fireVerifyCreate() {
        if (this.workflowDeisgner != null) {
            return this.workflowDeisgner.fireVerifyLinkCreate(this);
        }
        return false;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.DesignerElement
    protected boolean fireVerifyDelete() {
        if (this.workflowDeisgner != null && isInitialized()) {
            return this.workflowDeisgner.fireVerifyLinkDelete(this);
        }
        return false;
    }

    protected boolean fireVerifyChange(IFigureElement node, boolean sourceChanged) {
        if (this.workflowDeisgner != null && isInitialized()) {
            return this.workflowDeisgner.fireVerifyLinkChange(this, node, sourceChanged);
        }
        return false;
    }

    protected boolean fireVerifyCreateBendpoint(IBendpointElement bendpoint) {
        if (this.workflowDeisgner != null && isInitialized()) {
            return this.workflowDeisgner.fireVerifyBendpointCreate(this, bendpoint.getIndex(), bendpoint.getLocation());
        }
        return false;
    }

    protected boolean fireVerifyDeleteBendpoint(IBendpointElement bendpoint) {
        if (this.workflowDeisgner != null && isInitialized()) {
            return this.workflowDeisgner.fireVerifyBendpointDelete(this, bendpoint.getIndex());
        }
        return false;
    }

    protected boolean fireVerifyMoveBendpoint(IBendpointElement bendpoint) {
        if (this.workflowDeisgner != null && isInitialized()) {
            return this.workflowDeisgner.fireVerifyBendpointMove(this, bendpoint.getIndex(), bendpoint.getLocation());
        }
        return false;
    }
}
